import React, { useState } from 'react';
import { NsToggleSectionProps, NsAccordionItem } from '../';

/**
 * NsToggleSection takes prop `title` and prop `children` and toggles
 * children with animation when clicked on title
 *
 * it also has a `defaultOpen` prop, which when true, children is visible
 * by default, otherwise children is hidden by default and toggles between visible
 * and hidden on clicking title
 */
const NsToggleSection = ({ title, children, additionalProps, defaultOpen, variant }: NsToggleSectionProps) => {
    const [isExpanded, setIsExpanded] = useState(defaultOpen ?? false);

    const toggleAccordion = () => {
        setIsExpanded(!isExpanded);
    };
    return (
        <NsAccordionItem
            variant={variant}
            additionalProps={{ ...additionalProps, className: 'toggle-section ' + additionalProps?.className ?? '' }}
            isOpen={isExpanded}
            title={title}
            content={children}
            toggleOpen={toggleAccordion}
        />
    );
};

export default NsToggleSection;
