import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsAccordionHeader } from '@/common/index';

describe('NsAccordionHeader', () => {
    it('renders title correctly', () => {
        const onClick = jest.fn();
        const title = 'Section Header';
        const { getByText } = render(<NsAccordionHeader title={title} onClick={onClick} />);
        expect(getByText(title)).toBeInTheDocument();
    });

    it('calls onClick handler when clicked', () => {
        const onClick = jest.fn();
        const { container } = render(<NsAccordionHeader title="Section Header" onClick={onClick} />);
        const header = container.querySelector('header');
        if (header) {
            fireEvent.click(header);
            expect(onClick).toHaveBeenCalledTimes(1);
        }
    });

    it('renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const onClick = jest.fn();
        const { container } = render(
            <NsAccordionHeader
                title="Section Header"
                additionalProps={{ className: additionalClassName }}
                onClick={onClick}
            />
        );
        expect(container.querySelector('header')).toHaveClass(`section-header ${additionalClassName}`);
    });

    it('renders with expanded class when isOpen is true', () => {
        const onClick = jest.fn();
        const { container } = render(<NsAccordionHeader title="Section Header" isOpen onClick={onClick} />);
        expect(container.querySelector('header')).toHaveClass('expanded');
    });

    it('renders with header icon', () => {
        const onClick = jest.fn();
        const { getByTestId } = render(<NsAccordionHeader title="Section Header" onClick={onClick} />);
        expect(getByTestId('icon')).toBeInTheDocument();
    });
});
