import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsAccordionItem } from '@/common/index';

describe('NsAccordionItem', () => {
    const title = 'Accordion Section Title';
    const content = 'Accordion Section Content';

    it('renders title correctly', () => {
        const { getByText } = render(
            <NsAccordionItem isOpen={false} toggleOpen={() => {}} title={title} content={content} />
        );
        expect(getByText(title)).toBeInTheDocument();
    });

    it('calls toggleOpen function when clicked on the section header', () => {
        const toggleOpen = jest.fn();
        const { getByText } = render(
            <NsAccordionItem isOpen={false} toggleOpen={toggleOpen} title={title} content={content} />
        );
        fireEvent.click(getByText(title));
        expect(toggleOpen).toHaveBeenCalledTimes(1);
    });

    it('renders content when isOpen is true', () => {
        const { getByText } = render(
            <NsAccordionItem isOpen={true} toggleOpen={() => {}} title={title} content={content} />
        );
        expect(getByText(content)).toBeInTheDocument();
    });

    it('does not render content when isOpen is false', () => {
        const { queryByText } = render(
            <NsAccordionItem isOpen={false} toggleOpen={() => {}} title={title} content={content} />
        );
        expect(queryByText(content)).toBeNull();
    });
});
