import React from 'react';
import { render, screen } from '@/test-utils/index';
import { NsCollapse } from '@/common/index';

describe('NsCollapse', () => {
    it('renders children when isOpen is true', () => {
        const { getByText } = render(
            <NsCollapse isOpen>
                <div>Child 1</div>
                <div>Child 2</div>
            </NsCollapse>
        );
        expect(getByText('Child 1')).toBeInTheDocument();
        expect(getByText('Child 2')).toBeInTheDocument();
    });

    it('does not render children when isOpen is false', () => {
        render(
            <NsCollapse isOpen={false}>
                <div>Child 1</div>
                <div>Child 2</div>
            </NsCollapse>
        );
        expect(screen.queryByText('Child')).toBeNull();
    });

    it('renders with additional class name', () => {
        const additionalClassName = 'custom-class';
        const { container } = render(
            <NsCollapse additionalProps={{ className: additionalClassName }} isOpen>
                <div>Child 1</div>
                <div>Child 2</div>
            </NsCollapse>
        );
        expect(container.querySelector('section')).toHaveClass(`ns-collapse ${additionalClassName}`);
    });
});
