import React from 'react';
import { render, fireEvent } from '@/test-utils/index';
import { NsToggleSection } from '@/common/index';

describe('NsToggleSection', () => {
    const title = 'Toggle Section Title';
    const content = 'Toggle Section Content';

    it('renders title correctly', () => {
        const { getByText } = render(<NsToggleSection title={title}>{content}</NsToggleSection>);
        expect(getByText(title)).toBeInTheDocument();
    });

    it('toggles content visibility when clicked on the section header', () => {
        const { getByText, queryByText } = render(<NsToggleSection title={title}>{content}</NsToggleSection>);

        expect(queryByText(content)).toBeNull();
        fireEvent.click(getByText(title));
        expect(getByText(content)).toBeInTheDocument();
        fireEvent.click(getByText(title));
        expect(queryByText(content)).toBeNull();
    });

    it('sets defaultOpen prop correctly', () => {
        const { getByText } = render(
            <NsToggleSection title={title} defaultOpen>
                {content}
            </NsToggleSection>
        );

        expect(getByText(content)).toBeInTheDocument();
    });
});
