import type { StoryObj, Meta } from '@storybook/react';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import NsAccordion from '../NsAccordion';
import { contentArray } from './data';
import { AccordionVariant } from '../types.d';

type ComponentType = typeof NsAccordion;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/Accordion/NsAccordion',
    component: NsAccordion,
    decorators: [withCenterDecorator],
    argTypes: {
        allowMultipleExpanded: {
            control: 'boolean',
            description: `if true, then multiple sections can remain open at a same time, and if false,
            opening a section will close other sections of the accordion`,
        },
        contentArray: {
            description: ` this should be an array of objects, each object should have 3 properties,
            title, body and isDefaultOpen`,
        },
        variant: {
            control: 'select',
            options: [...Object.values(AccordionVariant)],
        },
    },
    args: {
        variant: AccordionVariant.Basic,
    },
} as MetaStory;

export const SingleOpen: Story = {
    args: {
        allowMultipleExpanded: false,
        contentArray,
    },
};

export const MultipleOpen: Story = {
    args: {
        allowMultipleExpanded: true,
        contentArray,
    },
};
