import { PropsWithChildren, ReactNode } from 'react';
import { AdditionalProps } from '../common.types';
import { NsIconNameType } from '../icon';
import { Variants } from '../typography';

export type NsAccordionHeaderProps = AdditionalProps & {
    title: string | ReactNode;
    // eslint-disable-next-line no-unused-vars
    onClick: (...args: any[]) => void;
    /** a flag for the header, based on which header can change properties */
    isOpen?: boolean;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
    variant: AccordionVariant;
    headerTypographyVariant?: Variants;
};

export type NsCollapseProps = AdditionalProps &
    PropsWithChildren<{
        isOpen: boolean;
        variant: AccordionVariant;
    }>;

export type NsFramerCollapseProps = NsCollapseProps & {
    transitionDetails?: {
        duration?: number;
        ease?: number[];
    };
};

export type NsToggleSectionProps = AdditionalProps &
    PropsWithChildren<{
        title: string | ReactNode;
        /** if true, NsToggle is rendered in open state, that collapsible section is visible */
        defaultOpen?: boolean;
        variant: AccordionVariant;
    }>;

export type NsAccordionItemProps = AdditionalProps & {
    isOpen: boolean;
    // eslint-disable-next-line no-unused-vars
    toggleOpen(index: number, isOpen: boolean): void;
    title: string | ReactNode;
    content: ReactNode;
    variant: AccordionVariant;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
};
export type NsAccordionProps = AdditionalProps & {
    allowMultipleExpanded: boolean;
    contentArray: {
        title: string | ReactNode;
        body: ReactNode;
        isDefaultOpen?: boolean;
    }[];
    variant: AccordionVariant;
    headerTypographyVariant?: Variants;
    /** NsIcon's icon name to be shown in opened state */
    openedIconName?: NsIconNameType;
    /** NsIcon's icon name to be shown in closed state */
    closedIconName?: NsIconNameType;
};
export enum AccordionVariant {
    // eslint-disable-next-line no-unused-vars
    Basic = 'basic', // basic is as per figma
    // eslint-disable-next-line no-unused-vars
    Compact = 'compact', // compact is as per test.nuskin.com
}
