/* eslint-disable max-len */
import { styled, css } from '@nuskin/foundation-theme';
import { getAppColor } from '@nuskin/foundation-theme/src/utils/color-utils';
import { FoundationTheme } from '@nuskin/foundation-theme/src/themes';

import type { AlertContainerParams, AlertType, AlertParams, TypeMapCSS } from './types.d';
const gutter_width = '10px';
const close_button_width = '12px';
const icon_width = '24px';

const TypeMap: TypeMapCSS = {
    banner: {
        'min-height': '114px',
        padding: '15px 45px',
        'content-column-start': 'row-center',
        'content-column-end': 'row-center',
        'bar-position': 'top',
        'foot-visibility': 'block',
    },
    card: {
        'min-height': '72px',
        padding: '24px 24px',
        'content-column-start': 'row-left',
        'content-column-end': 'row-right',
        'bar-position': 'left',
        'foot-display': 'none',
    },
};

const contextType = {
    error: 'red',
    info: 'info',
    notice: 'info',
    success: 'success',
    warning: 'warning',
};

export const AlertContainer = styled.div<AlertContainerParams>`
    display: ${({ visible }) => (visible ? 'block' : 'none')};
    * {
        box-sizing: border-box;
        webkit-font-smoothing: antialiased;
    }
    text-align: left;
`;

const fontFamilyStyles = css`
    font-family: 'proxima-nova', 'OpenSans', 'Pridi', 'NotoSans', 'NotoSansSC', 'NotoSansHebrew', 'NotoSansJapanese',
        'Hiragino Kaku Gothic Pro', 'Yu Gothic Medium', 'Yu Gothic', Meiryo, 'source-han-sans-japanese',
        'source-han-sans-korean', 'source-han-sans-simplified-c', Helvetica, Arial, sans-serif;
`;

export const Alert = styled.div<AlertParams>`
    position: relative;
    display: grid;
    grid-template-columns: [row-left] ${icon_width} [space] ${gutter_width} [row-center] auto [space] ${gutter_width} [row-right] ${close_button_width};
    grid-template-rows: [row1] auto;
    grid-auto-row: auto;
    grid-auto-flow: row;
    background-color: ${({ theme }) => getAppColor(theme, 'primary', 'white')};
    border: 1px solid ${({ theme }) => getAppColor(theme, 'primary', 'black')};
    min-height: ${({ type }) => TypeMap?.[type]?.['min-height']};
    padding: ${({ type }) => TypeMap?.[type]?.['padding']};
    color: ${({ context, theme }) => getAppColor(theme, contextType?.[context] as FoundationTheme.AppColors, '40')} };
`;

export const AlertCloseButton = styled.div`
    grid-column-start: row-right;
    grid-column-end: row-right;
    grid-row-start: row1;
    grid-row-end: row1;
    align-self: center;
    cursor: pointer;
`;

export const AlertIcon = styled.div`
    grid-column-start: row-left;
    grid-column-end: row-left;
    grid-row-start: row1;
    grid-row-end: row1;
    width: ${icon_width};
    height: ${icon_width};
`;

export const AlertHead = styled.div`
    grid-column-start: row-center;
    grid-column-end: row-center;
    grid-row-start: row1;
    grid-row-end: row1;
    display: flex;
    flex-direction: column;
    justify-content: center;
    span {
        ${fontFamilyStyles}
        color: ${({ theme }) => getAppColor(theme, 'primary', 'black')};
        font-weight: 600;
        font-size: 18px;
        line-height: 20px;
    }
`;

export const AlertContent = styled.div<{ type: AlertType }>`
    margin-top: 8px;
    color: ${({ theme }) => getAppColor(theme, 'primary', 'black')};
    grid-column-start: ${({ type }) => TypeMap?.[type]?.['content-column-start']};
    grid-column-end: ${({ type }) => TypeMap?.[type]?.['content-column-end']};
`;

export const AlertFoot = styled.div<{ type: AlertType }>`
    margin-top: 8px;
    color: ${({ theme }) => getAppColor(theme, 'primary', 'black')};
    display: ${({ type }) => TypeMap?.[type]?.['foot-display']};
    ${fontFamilyStyles}
    font-weight: 300;
    font-size: 14px;
    line-height: 18px;
`;

export const AlertBody = styled.div`
    ${fontFamilyStyles}
    font-weight: 300;
    font-size: 16px;
    line-height: 21px;
`;
