import { useState } from 'react';
import { NsIcon } from '../icon';
import {
    AuthDropdownContainer,
    AuthHead,
    Button,
    AuthDropdown,
    Triangle,
    SignInButton,
    SignUpLinkContainer,
    SignUpLink,
} from './NsAuthDropdown.styled';
import { NsAuthDropdownProps } from './types.d';

const NsAuthDropdown = ({
    signInRedirectLink,
    signUpRedirectLink,
    signInBtnText,
    signUpLinkText,
    signUpLinkPrefixText,
    titleText,
    closeOnMouseLeave = false,
}: NsAuthDropdownProps) => {
    const [isOpen, setIsOpen] = useState(false);

    const handleToggle = () => {
        setIsOpen((prevIsOpen) => !prevIsOpen);
    };

    const closeDropdown = () => {
        if (closeOnMouseLeave) {
            setIsOpen(false);
        }
    };

    return (
        <AuthDropdownContainer>
            <AuthHead data-testid="auth-head" onClick={handleToggle}>
                <Button>{titleText}</Button>
                <NsIcon testId="chevron-icon" name={isOpen ? 'arrowUp' : 'arrowDown'} color="primary" />
                {isOpen ? (
                    <div onMouseLeave={closeDropdown}>
                        <Triangle />
                        <AuthDropdown>
                            <SignInButton href={signInRedirectLink} data-testid="sign-in-btn">
                                {signInBtnText}
                            </SignInButton>
                            <SignUpLinkContainer>
                                {signUpLinkPrefixText}{' '}
                                <SignUpLink data-testid="signup-link" href={signUpRedirectLink}>
                                    {signUpLinkText}
                                </SignUpLink>
                            </SignUpLinkContainer>
                        </AuthDropdown>
                    </div>
                ) : null}
            </AuthHead>
        </AuthDropdownContainer>
    );
};

export default NsAuthDropdown;
