import React from 'react';
import { render, screen, waitFor } from '@/test-utils/index';
import { NsAutocomplete } from '@/common/index';
import { OptionUiComponent } from './mock/MockUI';
import { AutocompleteMockList } from './mock/MockData';
import userEvent from '@testing-library/user-event';
import { act } from 'react-dom/test-utils';

describe('CustomAutocomplete', () => {
    test('should render autocomplete component', () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                onSelect={() => {}}
                placeholder="autocomplete-input"
                renderOptions={OptionUiComponent}
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        expect(autocompleteInput).toBeInTheDocument();
    });

    test('displays options when typing in the input', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                onSelect={() => {}}
                renderOptions={OptionUiComponent}
                placeholder="autocomplete-input"
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(
            () => {
                const option1 = screen.getByText('GS Facial Gels 2pk Subscription');
                expect(option1).toBeInTheDocument();
            },
            { timeout: 5000 }
        );
    }, 40000);

    test('selects an option when clicking on it', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                renderOptions={OptionUiComponent}
                placeholder="autocomplete-input"
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const optionLi = screen.getByText('GS Facial Spa');
            userEvent.click(optionLi);
        });
    }, 40000);

    test('should load more options when clicking load more button', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                renderOptions={OptionUiComponent}
                placeholder="autocomplete-input"
                seeMore={{
                    text: '',
                    show: true,
                    onSeeMore: () => ({}),
                }}
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const loadMoreButton = screen.getByTestId('autocomplete-loadmore-id');
            userEvent.click(loadMoreButton);
        });
    }, 40000);

    test('should clear options when clicking clear button', async () => {
        render(
            <NsAutocomplete
                options={AutocompleteMockList}
                renderOptions={OptionUiComponent}
                placeholder="autocomplete-input"
                clear={{
                    text: '',
                    show: true,
                    onClear: () => ({}),
                }}
            />
        );
        const autocompleteInput = screen.getByPlaceholderText('autocomplete-input');
        act(() => {
            userEvent.type(autocompleteInput, 'GS Facial');
        });
        await waitFor(() => {
            const clearButton = screen.getByTestId('autocomplete-clear-id');
            userEvent.click(clearButton);
        });
    }, 40000);
});
