/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsAutocomplete.stories.tsx
 * @description NsAutocomplete component.
 */

import React from 'react';
import type { StoryObj, Meta } from '@storybook/react';

import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsAutocomplete } from './';
import { AutocompleteMockList } from './mock/MockData';
import { OptionUiComponent } from './mock/MockUI';
import { NsAutocompleteProps } from './types.d';
import { NsIcon } from '../icon';

type ComponentType = typeof NsAutocomplete;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    title: 'Components/NsAutocomplete',
    component: NsAutocomplete,
    decorators: [withCenterDecorator],
    argTypes: {
        children: {
            control: 'text',
        },
    },
    args: {
        options: AutocompleteMockList,
        seeMore: {
            text: 'See More Results',
            show: false,
            onSeeMore: () => {
                throw new Error('Function not implemented.');
            },
        },
        clear: {
            text: 'Clear Recent Searches',
            show: false,
            onClear: () => {
                throw new Error('Function not implemented.');
            },
        },
        iconStart: <NsIcon name="search" />,
        iconEnd: <NsIcon name="close" size='small'/>,
        placeholder: 'search',
    },
} as MetaStory;

export const Autocomplete: Story = {
    render: (args: NsAutocompleteProps) => <NsAutocomplete {...args} renderOptions={OptionUiComponent} />,
};
