/**
 * @author [Vijayaprathap Kumar] (vpkumar@nuskin.com)
 * NsBreadcrumb.tsx
 * @description NsBreadcrumb component with a navigation items array props
 */

import { PropsWithChildren } from 'react';

import { BreadcrumbContainer, BreadcrumbItem, BreadcrumbList } from './NsBreadcrumb.styled';
import { NsTypography, NsLink, NsIcon } from '../';
import { NsBreadcrumbProps, ItemProps } from './types.d';
import { useTheme } from '@mui/material/styles';
import { ColorUtils } from '@nuskin/foundation-theme';

const NsBreadcrumb = (props: PropsWithChildren<NsBreadcrumbProps>) => {
    const { items, iconVisibility } = props;

    const theme = useTheme();
    const neutral80 = ColorUtils.getAppColor(theme, 'neutral', '80') as string;
    const neutral60 = ColorUtils.getAppColor(theme, 'neutral', '60') as string;

    const getLabel = (item: ItemProps) => {
        if (item?.href) {
            return (
                <NsTypography variant="h6" colorOverride={neutral60}>
                    <NsLink href={item.href} underlineOnHover>
                        {iconVisibility && item.icon ? (
                            <NsIcon name={item.icon} size="small" testId="nav-icon" colorOverride={neutral60} />
                        ) : null}
                        {item.label}
                    </NsLink>
                </NsTypography>
            );
        } else {
            return (
                <NsTypography variant="h6" colorOverride={neutral80}>
                    {item.label}
                </NsTypography>
            );
        }
    };

    return (
        <BreadcrumbContainer aria-label="breadcrumb">
            <BreadcrumbList>
                {items?.map((item: ItemProps, index: number) => (
                    <BreadcrumbItem key={item.label}>
                        {getLabel(item)}
                        {index !== items.length - 1 ? (
                            <NsIcon className="slashIcon" name={'slash'} size="small" colorOverride={neutral60} />
                        ) : null}
                    </BreadcrumbItem>
                ))}
            </BreadcrumbList>
        </BreadcrumbContainer>
    );
};

export default NsBreadcrumb;
