import React from 'react';
import { render, screen } from '@/test-utils/index';
import nuskinTheme from '@nuskin/foundation-theme/src/themes/genome-foundation';
import Button from './NsButton';

const { palette } = nuskinTheme;

describe('<Button />', () => {
    describe(' button primary', () => {
        test('should render default button styles', () => {
            const text = 'Click Me';
            render(
                <Button color="primary" variant="contained">
                    {text}
                </Button>
            );

            const button = screen.getByText(text);
            expect(button).toBeInTheDocument();
            expect(button).toHaveStyle(`color: ${palette?.primary?.contrastText ?? ''}`);
            expect(button).toHaveStyle(`background-color: ${palette?.primary?.main ?? ''}`);
        });
    });
    describe('button secondary', () => {
        test('should render default button styles', () => {
            const text = 'Click Me';
            render(
                <Button color="success" variant="contained" size="large">
                    {text}
                </Button>
            );

            const button = screen.getByText(text);

            expect(button).toBeInTheDocument();
            expect(button).toHaveStyle(`color: ${palette.success.contrastText}`);
            expect(button).toHaveStyle(`background-color: ${palette.success.main}`);
        });
    });
    describe('button outline success', () => {
        test('should render outlined success button', () => {
            render(
                <Button color="success" variant="outlined" size="large">
                    Click Me
                </Button>
            );

            const button = screen.getByText('Click Me');

            expect(button).toBeInTheDocument();
            expect(button).toHaveStyle(`color: ${palette.success.main}`);
        });
    });
    describe('button outline accentColorA', () => {
        test('should render outlined success button', () => {
            render(
                <Button color="accentColorA" variant="outlined" size="large">
                    Click Me
                </Button>
            );

            const button = screen.getByText('Click Me');

            expect(button).toBeInTheDocument();
            expect(button).toHaveStyle(`color: ${palette?.accentColorA?.main}`);
        });
    });
});
