import type { StoryObj, Meta } from '@storybook/react';
import { within, userEvent } from '@storybook/testing-library';
import { expect } from '@storybook/jest';
import { withCenterDecorator } from '@/stories/decorators/withCenterDecorator';
import { NsFfgCard } from '../';

type ComponentType = typeof NsFfgCard;
type Story = StoryObj<ComponentType>;
type MetaStory = Meta<ComponentType>;

export default {
    component: NsFfgCard,
    title: 'Components/NsCard/NsFfgCard',
    argTypes: {},
    decorators: [withCenterDecorator],
} as MetaStory;

export const Default: Story = {
    args: {
        actionText: 'LEARN MORE',
        actionLink: 'https://www.forceforgood.org/',
        text: 'Every child deserves a chance to shine. Through our Nu Skin Force for Good Foundation, we’re empowering children around the world with hope for a brighter future.',
        topImageUrl:
            'https://images.contentstack.io/v3/assets/blt594f30e2dc643eae/blt34cdb300dc9b93ff/645ccaa7520ba1a1af13a08a/nsffg-foundation.webp',
        topImageAlt: 'Force for Good Foundation',
        additionalProps: {
            testid: 'ffg-card',
        },
    },
    play: async ({ canvasElement }) => {
        const canvas = within(canvasElement);
        await userEvent.hover(canvas.getByTestId('ffg-card'));
        await userEvent.hover(canvas.getByRole('link'));
        await expect(
            canvas.getByText(
                'Every child deserves a chance to shine. Through our Nu Skin Force for Good Foundation, we’re empowering children around the world with hope for a brighter future.'
            )
        ).toBeInTheDocument();
    },
};
