import { PropsWithChildren } from 'react';
import { AdditionalProps } from '../common.types';

/*
    options to be shown on content stack
		1 Column (100%)
		2 Columns (50%, 50%)
		2 Columns (33%, 67%)
		2 Columns (67%, 33%)
		3 Columns (33%, 33%, 33%)
		3 Columns (50%, 25%, 25%)
		3 Columns (25%, 25%, 50%)
		4 Columns (25%, 25%, 25%, 25%)
*/
export type NsColumnControlProps = PropsWithChildren<{
    /**
     * follows the convention of ns-col-lg-(column-ratio) (for large screens >= 960px),
     *  ns-col-md-(column-ratio) (for tablet screens >= 600px),
     *  and ns-col-sm-(column-ratio) (for mobile screens i.e < 600px)
     * sample values
     * 'ns-col-lg-2-1', 'ns-col-lg-1-2', 'ns-col-lg-1-1',
     */
    columnClass: string;
    gap?: number;
}> &
    AdditionalProps;

export type sizeObjectType = {
    fractions?: number[];
    tabletFractions?: number[];
    mobileFractions?: number[];
};

export type NsFlexColumnsProps = PropsWithChildren<{
    /**
     * follows the convention of ns-col-lg-{column-ratio}
     * sample value for column-ratio = 2-1 ==>ns-col-lg-2-1
     */
    columnClass: string;
    gap: number;
    /* when this boolean is true, column control takes full width of page instead of being restricted to 1200px */
    isFullWidth?: boolean;
}> &
    AdditionalProps;

export type NsGridColumnsProps = NsFlexColumnsProps;
