import { FormLabel } from '@mui/material';
import { NsLabelProps } from './types.d';
import { styled, ColorUtils } from '@nuskin/foundation-theme';
import { CSSProperties } from 'react';
const { getAppColor, getPaletteColor } = ColorUtils;

const StyledLabel = styled(FormLabel)<{ fontSize?: number; style?: CSSProperties }>(({ theme, fontSize, style }) => {
    const isLight = theme.palette?.primary?.main === '#252525';
    return {
        fontSize: fontSize ? `${fontSize}px` : '14px',
        textAlign: style?.textAlign ?? 'left',
        color: getPaletteColor(theme, 'primary', 'main'),
        '.optional-label': {
            color: isLight ? getAppColor(theme, 'neutral', '60') : getAppColor(theme, 'neutral', '50'),
        },
        '.MuiInputLabel-asterisk': {
            color: isLight ? getAppColor(theme, 'error', '40') : getAppColor(theme, 'error', '20'),
        },
        ...(style || {}),
    } as any; // TODO: may be this "any" has to be fixed from foundation-theme
});

const NsLabel = (props: NsLabelProps) => {
    const { required, showOptional, children, size } = props;
    return (
        <StyledLabel {...props} fontSize={size} required={required}>
            {children}
            {!required && showOptional ? <span className="optional-label">{' (Optional)'}</span> : null}
        </StyledLabel>
    );
};
export default NsLabel;
