import { FormControl } from '@mui/material';
import { NsRadioGroupProps } from './types';
import {
    StyledHelperText,
    StyledFormControlLabel,
    StyledRadio,
    StyledSpan,
    StyledRadioGroup,
} from './NsRadioGroup.styled';
import { NsLabel } from '../label';

const NsRadioGroup = (props: NsRadioGroupProps) => {
    const { items, additionalSlot, label, onChange, color, disable, size, additionalProps, labelFontSize } = props;

    return (
        <>
            <FormControl data-testid={additionalProps?.testid}>
                <NsLabel size={labelFontSize}>{label}</NsLabel>
                <StyledRadioGroup
                    aria-labelledby="demo-radio-buttons-group-label"
                    defaultValue={items?.[0]?.value}
                    name="radio-buttons-group"
                    onChange={onChange}
                    color={color}
                >
                    {items?.map((item, index) => (
                        <StyledFormControlLabel
                            id={`${index} `}
                            key={item?.id}
                            value={item?.value}
                            control={<StyledRadio className="custom-radio" />}
                            label={item?.label}
                            disabled={disable}
                        />
                    ))}
                </StyledRadioGroup>
            </FormControl>
            {additionalSlot && <StyledHelperText className={`ml-${size}`}>
                <StyledSpan className="text-sm">{additionalSlot}</StyledSpan>
            </StyledHelperText>}

        </>
    );
};

export default NsRadioGroup;
