import { styled, ColorUtils, FoundationTheme } from '@nuskin/foundation-theme';
const { getPaletteColor, getAppColor } = ColorUtils;

export const SelectContainer = styled.div<{ disabled: boolean }>`
    position: relative;
    display: inline-block;
    opacity: ${({ disabled }) => (disabled ? '0.5' : '1')};
`;

export const SelectHead = styled.div<{ type: string; disabled: boolean }>`
    cursor: ${({ disabled }) => (disabled ? 'inherit' : 'pointer')};
    padding: 5px 10px;
    display: flex;
    justify-content: space-between;
    align-items: center;
    border: ${({ type, theme }) =>
        type === 'outlined' ? `1px solid ${getAppColor(theme, 'primary', 'black')}` : 'none'};
    color: ${({ theme }) => getPaletteColor(theme, 'primary')};
    width: 207px;
    position: relative;
    z-index: 2;
`;

export const SelectButton = styled.div`
    padding-right: 10px;
`;

export const SelectList = styled.div<{ borderColor: FoundationTheme.PaletteColors }>`
    position: absolute;
    z-index: 100;
    border: 1px solid ${({ borderColor, theme }) => getPaletteColor(theme, borderColor)};
    padding: 0;
    margin: 0;
    width: -webkit-fill-available;
    color: ${({ theme }) => getPaletteColor(theme, 'primary', 'main')};
    background-color: ${({ theme }) => getPaletteColor(theme, 'primary', 'contrastText')};
`;
const getIsLight = (theme: FoundationTheme.Theme) => {
    const { palette = { primary: { main: '', contrastText: '' } } } = theme;
    return palette.primary.main === getAppColor(theme, 'primary', 'black');
};

const getDividerColor = (theme: FoundationTheme.Theme) => {
    const isLight = getIsLight(theme);
    const dividerColor = isLight ? getAppColor(theme, 'neutral', '30') : getAppColor(theme, 'neutral', '20');
    return dividerColor;
};
const getListBgColor = (theme: FoundationTheme.Theme) => {
    const isLight = getIsLight(theme);
    const bgColor = isLight ? getAppColor(theme, 'accentColorB', '10') : getAppColor(theme, 'accentColorB', '50');
    return bgColor;
};
export const ListItemContainer = styled.div<{ showListDivider: boolean; isSelected: boolean }>`
     ${({ showListDivider, isSelected, theme }) => `
        cursor: pointer;
        padding: 5px 0;
        border-bottom: 1px solid ${showListDivider ? getDividerColor(theme) : 'none'};
        background-color: ${isSelected ? getPaletteColor(theme, 'primary') : 'white'};
        color: ${isSelected ? 'white' : 'black'};

        &:hover {
            background-color: ${getListBgColor(theme)};
        }

        &:last-child {
            border-bottom: none;
        }
    `}
`;

export const ListItem = styled.div<{ isSelected: boolean}>`
    padding: 5px 10px;
    border-left: ${({ isSelected, theme }) =>
        isSelected ? `2px solid ${getPaletteColor(theme, 'primary')}` : 'none'};
    background-color: ${({ isSelected, theme }) =>
        isSelected ? getPaletteColor(theme, 'primary', 'main') : 'white'};
    color: ${({ isSelected }) => (isSelected ? 'white' : 'black')};
    &:hover {
        background-color: ${({ isSelected, theme }) =>
        isSelected ? getPaletteColor(theme, 'primary', 'main') : getListBgColor(theme)};
            font-weight: bold; 
    }
`;

export const SelectLabel = styled.label`
    display: block;
    margin-bottom: 5px;
    color: ${({ theme }) => getPaletteColor(theme, 'primary')};
`;
